@@ -1,5 +1,6 @@
 import pytest
-from sync_pre_commit_lock.utils import normalize_git_url
+
+from sync_pre_commit_lock.utils import normalize_git_url, url_diff
 
 
 # Here are the test cases
@@ -22,3 +23,17 @@ from sync_pre_commit_lock.utils import normalize_git_url
 )
 def test_normalize_git_url(url: str, expected: str) -> None:
     assert normalize_git_url(url) == expected
+
+
+@pytest.mark.parametrize(
+    "old,new,expected",
+    [
+        ("https://some.place", "https://some.place", "https://some.place"),
+        ("https://some.old.place", "https://some.new.place", "https://some.{old -> new}.place"),
+        ("https://some.place", "https://another.place", "https://{some -> another}.place"),
+        ("https://some.place/old", "https://a.different/place", "https://{some.place/old -> a.different/place}"),
+        ("https://some.place/old", "https://some.place/new", "https://some.place/{old -> new}"),
+    ],
+)
+def test_url_diff(old: str, new: str, expected: str):
+    assert url_diff(old, new) == expected
